@@ -176,7 +176,7 @@ pool_read(POOL_CONNECTION * cp, void *buf, int len)
 			{
 				ereport(ERROR,
 						(errmsg("unable to read data from DB node %d", cp->db_node_id),
-						 errdetail("pool_check_fd call failed with an error \"%s\"", strerror(errno))));
+						 errdetail("pool_check_fd call failed with error \"%m\"")));
 			}
 		}
 
@@ -210,7 +210,7 @@ pool_read(POOL_CONNECTION * cp, void *buf, int len)
 			if (errno == EINTR || errno == EAGAIN)
 			{
 				ereport(DEBUG5,
-						(errmsg("read on socket failed with error :\"%s\"", strerror(errno)),
+						(errmsg("read on socket failed with error :\"%m\""),
 						 errdetail("retrying...")));
 				continue;
 			}
@@ -238,20 +238,20 @@ pool_read(POOL_CONNECTION * cp, void *buf, int len)
 					child_exit(POOL_EXIT_AND_RESTART);
 					ereport(ERROR,
 							(errmsg("unable to read data from DB node %d", cp->db_node_id),
-							 errdetail("socket read failed with an error \"%s\"", strerror(errno))));
+							 errdetail("socket read failed with error \"%m\"")));
 				}
 				else
 				{
 					ereport(ERROR,
 							(errmsg("unable to read data from DB node %d", cp->db_node_id),
-							 errdetail("socket read failed with an error \"%s\"", strerror(errno))));
+							 errdetail("socket read failed with error \"%m\"")));
 				}
 			}
 			else
 			{
 				ereport(FRONTEND_ERROR,
 						(errmsg("unable to read data from frontend"),
-						 errdetail("socket read failed with an error \"%s\"", strerror(errno))));
+						 errdetail("socket read failed with error \"%m\"")));
 			}
 		}
 		else if (readlen == 0)
@@ -340,7 +340,7 @@ pool_read2(POOL_CONNECTION * cp, int len)
 			{
 				ereport(ERROR,
 						(errmsg("unable to read data from DB node %d", cp->db_node_id),
-						 errdetail("pool_check_fd call failed with an error \"%s\"", strerror(errno))));
+						 errdetail("pool_check_fd call failed with error \"%m\"")));
 			}
 		}
 
@@ -362,7 +362,7 @@ pool_read2(POOL_CONNECTION * cp, int len)
 			if (errno == EINTR || errno == EAGAIN)
 			{
 				ereport(DEBUG5,
-						(errmsg("read on socket failed with error :\"%s\"", strerror(errno)),
+						(errmsg("read on socket failed with error :\"%m\""),
 						 errdetail("retrying...")));
 				continue;
 			}
@@ -389,7 +389,7 @@ pool_read2(POOL_CONNECTION * cp, int len)
 					/* we are in main process */
 					ereport(ERROR,
 							(errmsg("unable to read data from DB node %d", cp->db_node_id),
-							 errdetail("socket read failed with an error \"%s\"", strerror(errno))));
+							 errdetail("socket read failed with error \"%m\"")));
 				}
 				else
 				{
@@ -610,11 +610,11 @@ pool_write_flush(POOL_CONNECTION * cp, void *buf, int len)
 			 */
 			if (cp->isbackend)
 				ereport(WARNING,
-						(errmsg("write on backend %d failed with error :\"%s\"", cp->db_node_id, strerror(errno)),
+						(errmsg("write on backend %d failed with error :\"%m\"", cp->db_node_id),
 						 errdetail("while trying to write data from offset: %d wlen: %d", offset, wlen)));
 			else
 				ereport(DEBUG5,
-						(errmsg("write on frontend failed with error :\"%s\"", strerror(errno)),
+						(errmsg("write on frontend failed with error :\"%m\""),
 						 errdetail("while trying to write data from offset: %d wlen: %d", offset, wlen)));
 			return -1;
 		}
@@ -701,11 +701,11 @@ pool_flush_it(POOL_CONNECTION * cp)
 			 */
 			if (cp->isbackend)
 				ereport(WARNING,
-						(errmsg("write on backend %d failed with error :\"%s\"", cp->db_node_id, strerror(errno)),
+						(errmsg("write on backend %d failed with error :\"%m\"", cp->db_node_id),
 						 errdetail("while trying to write data from offset: %d wlen: %d", offset, wlen)));
 			else
 				ereport(DEBUG5,
-						(errmsg("write on frontend failed with error :\"%s\"", strerror(errno)),
+						(errmsg("write on frontend failed with error :\"%m\""),
 						 errdetail("while trying to write data from offset: %d wlen: %d", offset, wlen)));
 			cp->wbufpo = 0;
 			return -1;
@@ -944,7 +944,7 @@ pool_read_string(POOL_CONNECTION * cp, int *len, int line)
 			{
 				ereport(ERROR,
 						(errmsg("unable to read data from DB node %d", cp->db_node_id),
-						 errdetail("pool_check_fd call failed with an error \"%s\"", strerror(errno))));
+						 errdetail("pool_check_fd call failed with error \"%m\"")));
 			}
 		}
 
@@ -1290,14 +1290,14 @@ pool_set_nonblock(int fd)
 	{
 		ereport(FATAL,
 				(errmsg("unable to set options on socket"),
-				 errdetail("fcntl system call failed with error \"%s\"", strerror(errno))));
+				 errdetail("fcntl system call failed with error \"%m\"")));
 
 	}
 	if (fcntl(fd, F_SETFL, var | O_NONBLOCK) == -1)
 	{
 		ereport(FATAL,
 				(errmsg("unable to set options on socket"),
-				 errdetail("fcntl system call failed with error \"%s\"", strerror(errno))));
+				 errdetail("fcntl system call failed with error \"%m\"")));
 	}
 }
 
@@ -1315,13 +1315,13 @@ pool_unset_nonblock(int fd)
 	{
 		ereport(FATAL,
 				(errmsg("unable to set options on socket"),
-				 errdetail("fcntl system call failed with error \"%s\"", strerror(errno))));
+				 errdetail("fcntl system call failed with error \"%m\"")));
 	}
 	if (fcntl(fd, F_SETFL, var & ~O_NONBLOCK) == -1)
 	{
 		ereport(FATAL,
 				(errmsg("unable to set options on socket"),
-				 errdetail("fcntl system call failed with error \"%s\"", strerror(errno))));
+				 errdetail("fcntl system call failed with error \"%m\"")));
 	}
 }
 
@@ -1354,12 +1354,13 @@ socket_write(int fd, void *buf, size_t len)
 			if (errno == EINTR || errno == EAGAIN)
 			{
 				ereport(DEBUG5,
-						(errmsg("write on socket failed with error :\"%s\"", strerror(errno)),
+						(errmsg("write on socket failed with error :\"%m\""),
 						 errdetail("retrying...")));
 				continue;
 			}
 			ereport(LOG,
-					(errmsg("write on socket failed with error :\"%s\"", strerror(errno))));
+					(errmsg("write on socket failed"),
+					 errdetail("%m")));
 			return -1;
 		}
 		bytes_send += ret;
@@ -1393,7 +1394,8 @@ socket_read(int fd, void *buf, size_t len, int timeout)
 				continue;
 
 			ereport(WARNING,
-					(errmsg("select failed with error: \"%s\"", strerror(errno))));
+					(errmsg("system call select failed"),
+					 errdetail("%m")));
 			return -1;
 		}
 		else if (fds == 0)
@@ -1406,12 +1408,13 @@ socket_read(int fd, void *buf, size_t len, int timeout)
 			if (errno == EINTR || errno == EAGAIN)
 			{
 				ereport(DEBUG5,
-						(errmsg("read from socket failed with error :\"%s\"", strerror(errno)),
+						(errmsg("read from socket failed with error :\"%m\""),
 						 errdetail("retrying...")));
 				continue;
 			}
 			ereport(LOG,
-					(errmsg("read from socket failed with error :\"%s\"", strerror(errno))));
+					(errmsg("read from socket failed"),
+					 errdetail("%m")));
 			return -1;
 		}
 		if (ret == 0)
